PunctuatedExt

Trait PunctuatedExt 

pub trait PunctuatedExt<T, P> {
    // Required method
    fn remove(&mut self, index: usize) -> Pair<T, P>
       where P: Default;
}
Required Methods

fn remove(&mut self, index: usize) -> Pair<T, P>
where P: Default,

Removes and returns the element at position index, popping all elements after it and push them back.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T, P> PunctuatedExt<T, P> for Punctuated<T, P>

Source

fn remove(&mut self, index: usize) -> Pair<T, P>
where P: Default,

Implementors